@@ -1,7 +1,7 @@
 package Complete::Bash;
 
 our $DATE = '2015-12-30'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 use 5.010001;
 use strict;
@@ -221,7 +221,7 @@ sub parse_cmdline {
                       if ($opts && $opts->{truncate_current_word} &&
                               $is_cur_word && $pos > $point) {
                           $chunk = substr(
-                              $chunk, 0, length($chunk)-($pos-$point)+1);
+                              $chunk, 0, length($chunk)-($pos-$point));
                       }
                       if ($after_ws) {
                           push @words, $chunk;
@@ -549,7 +549,7 @@ Complete::Bash - Completion module for bash shell
 
 =head1 VERSION
 
-This document describes version 0.23 of Complete::Bash (from Perl distribution Complete-Bash), released on 2015-12-30.
+This document describes version 0.24 of Complete::Bash (from Perl distribution Complete-Bash), released on 2015-12-30.
 
 =head1 DESCRIPTION
 
